# Changelog

## 0.2.2 (2020-06-05)

- Update Python module to point to _beta_ NPM module via unpkg for now

## 0.2.1 (2020-06-04)

- Update Python module to point to released NPM module via unpkg, instead of serving directly from Github. #77

## 0.2.0 (2020-05-26)

- Set `vis_params` as the second positional argument #56
- Use a minified bundle #51
- Option to set a custom EE Layer bundle url #31

## 0.1.1 (2020-04-27)

- Include `requirements.txt` and `requirements_dev.txt` in `MANIFEST.in` to fix install.

## 0.1.0 (2020-04-23)

- First release on PyPI.
